@@ -10,6 +10,8 @@ from PyQt4.QtGui import QProgressDialog, QApplication
 from AppLocaleSetupDialog import AppLocaleSetupDialog
 from CachedStockQuoter import CachedStockQuoter
 from UpdateIntervalDialog import UpdateIntervalDialog
+from TransactionsModelPortrait import TransactionsModelPortrait
+from TransactionsModelLandscape import TransactionsModelLandscape
 
 class MMController(QObject):
 
@@ -24,7 +26,7 @@ class MMController(QObject):
     def setLoginDialog(self, loginDialog):
         self.loginDialog = loginDialog
         self.connect(self.loginDialog,
-                     SIGNAL("credentialsEntered(string, string)"),
+                     SIGNAL("credentialsEntered(QString, QString)"),
                      self.processCredentials)
         self.connect(self.loginDialog,
                      SIGNAL("accepted()"),
@@ -39,7 +41,7 @@ class MMController(QObject):
 
         self.connect(self.mainWindow.positionsListView,
                      SIGNAL("doubleClicked(QModelIndex)"),
-                     self.mainWindow.positionDoubleClicked)
+                     self.mainWindow.showTransactionsForPosition)
 
         self.connect(self.mainWindow.portfolioListView,
                      SIGNAL("activated(int)"),
@@ -141,11 +143,28 @@ class MMController(QObject):
             portfolioPositions[i]['name'] = position.symbol.full_name
             portfolioPositions[i]['change'] = "0.0"
             portfolioPositions[i]['changePct'] = "0.0%"
+            # Save the position object such that transactions can be fetched later on
+            portfolioPositions[i]['position'] = position
 
             i = i + 1
 
         return portfolioPositions
 
+    '''
+    @param positionData - PostionData
+    @return TransactionsModel
+    '''
+    def createTransactionModel(self, positionData):
+        transactionFeed = self.gDataClient.GetTransactionFeed(positionData)
+        # list of gdata.finance.TransactionEntry objects
+        transactions = transactionFeed.entry
+        prop = MaeMoneyProperties.instance()
+        if prop.isPortraitMode():
+            transactionModel = TransactionsModelPortrait(transactions)
+        else:
+            transactionModel = TransactionsModelLandscape(transactions)
+        return transactionModel
+
     def createPortfolioListModel(self):
 
         portfolios = self.getPortfolios()
